# Subsetting PyRles

Rles can be subsetted on Chromosome, Strand or Chromosome/Strand pairs

```{python tidy=FALSE}
import pyranges as pr

gr = pr.data.chipseq()
c = gr.to_rle()
print(c["chr1"])
print(c["chr1", "+"])
print(c["-"])
```

To get the coverage of one or more intervals, you can use a PyRanges-object to subset the PyRles

```{python tidy=FALSE}
import pyranges as pr
f1 = pr.data.f1()
print(f1)
f1_c = f1.to_rle()
print(f1_c)

print(f1_c[f1])
```